@@ -1,6 +1,7 @@
 import datetime as dt
 import pandas as pd
 from googlewrapper.connect import Connection
+from numpy import nan
 
 
 class GoogleSearchConsole:
@@ -161,7 +162,8 @@ class GoogleSearchConsole:
             df["Branded"] = self.check_branded(df["Query"])
 
         # convert to datetime
-        df["Date"] = pd.to_datetime(df["Date"])
+        if 'Date' in df.columns:
+            df["Date"] = pd.to_datetime(df["Date"])
 
         df[["Clicks", "Impressions"]] = df[["Clicks", "Impressions"]].astype(int)
 
@@ -173,8 +175,11 @@ class GoogleSearchConsole:
 
         Returns as pd.Series of Bool if the query is branded
         """
+        branded_list = self._branded_dict[self._current_site]
+        if branded_list in [nan,[],['']]:
+            return False
         return pd.Series(query_list).str.contains(
-            "|".join(self._branded_dict[self._current_site]), na=False
+            "|".join(branded_list), na=False
         )
 
     def get_data(self):
